#include "pppconfig.h"
#include <qapplication.h>
#include <qtabwidget.h>

#define SN_API_NOT_YET_FROZEN 1
#include <libsn/sn.h>
static SnDisplay *sn_dpy;

int main( int argc, char **argv )
{
    QApplication a( argc, argv );
    PPPConfig lan;

    sn_dpy = sn_display_new (QPaintDevice::x_appdisplay, NULL, NULL);

    a.setMainWidget( &lan );
    if ( QApplication::desktop()->width() > 480 )
	lan.show();
    else
	lan.showMaximized();
    return a.exec();
}
